import 'package:cruiser/src/models/cruiser_args.dart';
import 'package:cruiser/src/models/cruiser_param.dart';
import 'package:cruiser/src/transitions/cruiser_transition.dart';
import 'package:cruiser/src/transitions/custom_cruiser_transition.dart';
import 'package:flutter/animation.dart';

class ArgumentsWrapper 
{
    final CruiserArgs cruiserArgs;
    final List<CruiserTransition> transitions;
    final Duration transitionDuration;
    final Curve transitionCurve;
    final Map<String, dynamic> params;

    /// Route params that are initially defined for the Route.
    /// Note: These are needed here, because user must be able to retrieve
    /// params from within the launched route. Since the only thing available
    /// from inside a launched route are arguments, these paramters are provided
    /// along with the arguments.
    final Map<String, CruiserParam> routeParams;

    final CustomCruiserTransition customTransition;

    ArgumentsWrapper
    ({
        this.cruiserArgs,
        this.transitions,
        this.transitionDuration,
        this.transitionCurve,
        this.params,
        this.routeParams,
        this.customTransition,
    });

    ArgumentsWrapper copyWith
    ({
        CruiserArgs cruiserArgs,
        List<CruiserTransition> transitions,
        Duration transitionDuration,
        Curve transitionCurve,
        List<CruiserParam> params,
        Map<String, CruiserParam> routeParams,
        CustomCruiserTransition customTransition,
    }) 
    {
        return ArgumentsWrapper(
            cruiserArgs: cruiserArgs ?? this.cruiserArgs,
            transitions: transitions ?? this.transitions,
            transitionDuration: transitionDuration ?? this.transitionDuration,
            transitionCurve: transitionCurve ?? this.transitionCurve,
            params: params ?? this.params,
            routeParams: routeParams ?? this.routeParams,
            customTransition: customTransition ?? this.customTransition,
        );
    }

    @override
    String toString() 
    {
        return 
            'ArgumentsWrapper{cruiserArgs: $cruiserArgs, '
            'transitions: $transitions, '
            'transitionDuration: $transitionDuration, '
            'transitionCurve: $transitionCurve}, '
            'params: $params, '
            'customTransition: $customTransition';
    }
}
