import 'package:cruiser/src/transitions/cruiser_transition.dart';
import 'package:cruiser/src/transitions/custom_cruiser_transition.dart';
import 'package:flutter/animation.dart';
import 'package:flutter/material.dart';

/// Options to configure a Cruiser instance.
class CruiserOptions 
{
    final bool handleNameNotFoundUI;

    /// Should display logs in console. Cruiser prints some useful logs
    /// which can be helpful during development.
    ///
    /// By default logs are disabled i.e. value is set to [false].
    final bool isLoggingEnabled;

    /// Default transitions for all the routes.
    /// Whatever transitions are provided in this list will be
    /// applied to every page launched using Cruiser.
    ///
    /// These transitions are overridden by default route transitions and
    /// transitions provided when routing using Cruiser's navigate method.
    final List<CruiserTransition> defaultTransitions;

    /// Default duration for all the transitions.
    ///
    /// This duration is overridden by default route duration and duration
    /// provided when routing using Cruiser's navigate method.
    final Duration defaultTransitionDuration;

    /// Default curve for all the transitions.
    ///
    /// This curve is overridden by default route curve and curve
    /// provided when routing using Cruiser's navigate method.
    final Curve defaultTransitionCurve;

    /// Provide a custom transition to cruiser instead of using
    /// inbuilt transitions, if not provided, cruiser will revert
    /// to use its default transitions or delegate to system's own
    /// transitions.
    final CustomCruiserTransition customTransition;

    /// A navigator key lets Cruiser grab the [NavigatorState] from a [MaterialApp]
    /// or a [CupertinoApp]. All navigation operations (push, pop, etc) are carried
    /// out using this [NavigatorState].
    ///
    /// This is the same [NavigatorState] that is returned by [Navigator.of(context)]
    /// (when there is only a single [Navigator] in Widget tree, i.e. from [MaterialApp]
    /// or [CupertinoApp]).
    final GlobalKey<NavigatorState> navigatorKey;

    const CruiserOptions
    ({
        this.handleNameNotFoundUI = false,
        this.isLoggingEnabled = false,
        this.defaultTransitions,
        this.defaultTransitionDuration,
        this.defaultTransitionCurve,
        this.customTransition,
        this.navigatorKey,
    })  : assert(handleNameNotFoundUI != null),
          assert(isLoggingEnabled != null);
}
