import 'package:cruiser/src/cruiser.dart';
import 'package:cruiser/src/models/cruiser_args.dart';
import 'package:cruiser/src/models/cruiser_param.dart';
import 'package:cruiser/src/models/param_map.dart';
import 'package:cruiser/src/transitions/cruiser_transition.dart';
import 'package:cruiser/src/transitions/custom_cruiser_transition.dart';
import 'package:flutter/widgets.dart';

typedef CruiserRouteBuilder = Widget Function
(
    BuildContext context,
    CruiserArgs args,
    ParamMap paramMap,
);

class CruiserRoute 
{
    final String name;
    final CruiserRouteBuilder builder;
    final CruiserArgs defaultArgs;
    final List<CruiserTransition> defaultTransitions;
    final Duration defaultTransitionDuration;
    final Curve defaultTransitionCurve;
    final List<CruiserParam> params;

    /// Provide a custom transition to cruiser instead of using
    /// inbuilt transitions, if not provided, cruiser will revert
    /// to use its default transitions or delegate to systems own
    /// transitions.
    final CustomCruiserTransition customTransition;

    const CruiserRoute
    ({
        @required this.name,
        @required this.builder,
        this.defaultArgs,
        this.defaultTransitions,
        this.defaultTransitionDuration,
        this.defaultTransitionCurve,
        this.params,
        this.customTransition,
    })  : assert(name != null), assert(builder != null);
}
