import 'package:cruiser/src/transitions/base_transition_page_route.dart';
import 'package:cruiser/src/transitions/concrete_transition_component.dart';
import 'package:cruiser/src/transitions/cruiser_transition.dart';
import 'package:cruiser/src/transitions/custom_cruiser_transition.dart';
import 'package:cruiser/src/transitions/decorators/fade_in_transition_decorator.dart';
import 'package:cruiser/src/transitions/decorators/slide_bottom_transition_decorator.dart';
import 'package:cruiser/src/transitions/decorators/slide_left_transition_decorator.dart';
import 'package:cruiser/src/transitions/decorators/slide_right_transition_decorator.dart';
import 'package:cruiser/src/transitions/decorators/slide_top_transition_decorator.dart';
import 'package:cruiser/src/transitions/decorators/zoom_in_transition_decorator.dart';
import 'package:cruiser/src/transitions/transition_component.dart';
import 'package:flutter/material.dart';

class TransitionFactory 
{
    static PageRoute buildTransition({
        RouteSettings settings,
        WidgetBuilder builder,
        Duration duration,
        Curve curve,
        List<CruiserTransition> transitions,
        CustomCruiserTransition customTransition,
    }) 
    {
        TransitionComponent transitionComponent = ConcreteTransitionComponent();

        transitions?.forEach((transition) 
        {
            switch (transition) 
            {
                case CruiserTransition.slideFromLeft:
                {
                    transitionComponent = SlideLeftTransitionDecorator(transitionComponent: transitionComponent);
                    break;
                }
                case CruiserTransition.slideFromBottom:
                {
                    transitionComponent = SlideDownTransitionDecorator(transitionComponent: transitionComponent);
                    break;
                }
                case CruiserTransition.slideFromTop:
                {
                    transitionComponent = SlideTopTransitionDecorator(transitionComponent: transitionComponent);
                    break;
                }
                case CruiserTransition.slideFromRight:
                {
                    transitionComponent = SlideRightTransitionDecorator(transitionComponent: transitionComponent);
                    break;
                }
                case CruiserTransition.zoomIn:
                {
                    transitionComponent = ZoomInTransitionDecorator(transitionComponent: transitionComponent);
                    break; 
                }
                case CruiserTransition.fadeIn:
                {
                    transitionComponent = FadeInTransitionDecorator(transitionComponent: transitionComponent);
                    break;
                }  
            }
        });

        return BaseTransitionPageRoute(
            settings: settings,
            builder: builder,
            transitionComponent: transitionComponent,
            duration: duration,
            curve: curve,
            useDefaultPageTransition: transitions == null || transitions.isEmpty,
            customTransition: customTransition,
        );
  }
}
